@@ -156,21 +156,39 @@ class BaseballReferenceScraper:
 
         fielding_metrics_by_position = soup_for_homepage_stats.find_all('tr', attrs = {'id': '{}:standard_fielding'.format(self.year)})
 
+        # POSITIONAL TZR
         all_positions = {}
         for index, position_info in enumerate(fielding_metrics_by_position, 1):
             # PARSE POSITION ATTRIBUTES
             position_name = position_info.find('td', attrs={'class':'left','data-stat':'pos'}).get_text()
             games_played = position_info.find('td',attrs={'class':'right','data-stat':'G'}).get_text()
+            # TOTAL ZONE (1953-2003)
             total_zone_object = position_info.find('td',attrs={'class':'right','data-stat':'tz_runs_total'})
             total_zone_rating = total_zone_object.get_text() if total_zone_object != None else 0
+            total_zone_rating = 0 if total_zone_rating == '' else total_zone_rating
+            # DRS (2003+)
+            drs_metric_name = 'bis_runs_total_per_season' if str(self.year) == '2020' else 'bis_runs_total'
+            drs_object = position_info.find('td',attrs={'class':'right','data-stat':drs_metric_name})
+            drs_rating = drs_object.get_text() if drs_object != None else 0
+            drs_rating = 0 if drs_rating == '' else drs_rating
             # UPDATE POSITION DICTIONARY
             position_dict = {
                 'Position{}'.format(index): position_name,
                 'gPosition{}'.format(index): games_played if games_played != '' else 0,
-                'tzPosition{}'.format(index): total_zone_rating
+                'tzPosition{}'.format(index): total_zone_rating,
+                'drsPosition{}'.format(index): drs_rating
             }
             all_positions.update(position_dict)
 
+        # GET DEFENSIVE WAR IN CASE OF LACK OF TZR AVAILABILITY FOR SEASONS < 1952
+        try:
+            player_value = soup_for_homepage_stats.find('tr', attrs = {'id': 'batting_value.{}'.format(self.year)})
+            dwar_object = player_value.find('td',attrs={'class':'right','data-stat':'WAR_def'})
+            dwar_rating = dwar_object.get_text() if dwar_object != None else 0
+            all_positions.update({'dWAR': dwar_rating})
+        except:
+            all_positions.update({'dWAR': 0})
+
         return all_positions
 
     def hand(self, soup_for_homepage_stats, type):
@@ -237,7 +255,7 @@ class BaseballReferenceScraper:
 
         games_as_pitcher = 0
         games_as_hitter = 0
-        positions = int(len(positional_fielding) / 3)
+        positions = int((len(positional_fielding)-1) / 4)
         # SPLIT GAMES BETWEEN TYPES
         for position_index in range(1, positions + 1):
             games = int(positional_fielding['gPosition{}'.format(position_index)])
@@ -289,7 +307,8 @@ class BaseballReferenceScraper:
 
         for player_dict in speed_list_all_players:
             # FIND PLAYER IN LIST
-            is_player_match = self.name.split(' ')[0] in player_dict['name_display_last_first'] \
+            first_name_cleaned = self.name.split(' ')[0].replace(".", "")
+            is_player_match = first_name_cleaned in player_dict['name_display_last_first'] \
                               and self.name.split(' ')[1] in player_dict['name_display_last_first']
             if is_player_match:
                 speed = float(player_dict['r_sprint_speed_top50percent_pretty'])
@@ -319,7 +338,10 @@ class BaseballReferenceScraper:
         standard_table_key = '{}_standard.{}'.format(table_prefix, self.year)
         standard_table = soup_for_advanced_stats.find('tr',attrs={'class':'full','id': standard_table_key})
 
-        advanced_stats = {}
+        is_rookie_season = self.__is_rookie_season(table_prefix=table_prefix, advanced_stats_soup=soup_for_advanced_stats)
+        
+        advanced_stats = {'is_rookie': is_rookie_season}
+
         # BATTING AGAINST (PITCHERS ONLY)
         if type == 'Pitcher':
             batting_against_table = soup_for_advanced_stats.find('tr',attrs={'class':'full','id': 'pitching_batting.{}'.format(self.year)})
@@ -356,6 +378,11 @@ class BaseballReferenceScraper:
 
         for category in standard_table:
             stat_category = category['data-stat']
+            # SAVE THIS INFO FOR RP ICON
+            if stat_category == 'SV':
+                # LEAGUE LEADERS ON BASEBALL REF ARE DENOTED BY BOLD TEXT
+                is_league_leader = '<strong>' in str(category)
+                standard_stats_dict['is_sv_leader'] = is_league_leader
             stat = category.get_text()
             if type == 'Pitcher':
                 pitching_categories = ['earned_run_avg','GS','W','SV','IP','award_summary']
@@ -447,6 +474,25 @@ class BaseballReferenceScraper:
         except:
             return 'TOT'
 
+    def __is_rookie_season(self, table_prefix, advanced_stats_soup):
+        """Checks to see if the selected season is the player's rookie season
+
+        Args:
+          table_prefix: String for whether player is batter or pitcher
+          advanced_stats_soup: BeautifulSoup object for advanced stats table.
+
+        Returns:
+          TRUE or FALSE bool
+        """
+        try:
+            full_element_prefix = '{}_standard.'.format(table_prefix)
+            all_seasons_list = advanced_stats_soup.find_all('tr',attrs={'class':'full','id': re.compile(full_element_prefix)})
+            first_season = all_seasons_list[0].find('th',attrs={'class':'left','data-stat': 'year_ID'} )
+            year_of_first_season = str(first_season["csk"])
+            return year_of_first_season == str(self.year)
+        except:
+            return False
+
 # ------------------------------------------------------------------------
 # HELPER METHODS
 
